@@ -10,7 +10,7 @@ use Moo::Role;
 use experimental 'signatures';
 use namespace::clean;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub _convert ( $self, $bignum ) {
     require Ref::Util;
@@ -44,7 +44,7 @@ CXC::Number::Grid::Role::PDL - Role to return PDL objects
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -56,15 +56,23 @@ version 0.06
 A L<Moo> role providing a C<_convert> method which returns passed
 L<Math::BigFloat> arrays as piddles and passed L<Math::BigFloat> scalars as Perl numbers.
 
-=head1 BUGS
+=head1 INTERNALS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
-to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
+=head1 SUPPORT
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/cxc-number
+
+and may be cloned from
+
+  https://gitlab.com/djerius/cxc-number.git
 
 =head1 SEE ALSO
 
