@@ -5,7 +5,7 @@ package CXC::Number::Grid::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Math::BigInt upgrade => 'Math::BigFloat';
 use Math::BigFloat;
@@ -27,19 +27,15 @@ BEGIN { extends( "CXC::Number::Types" ) }
 
 
 
-declare BinEdges,
-  as ArrayRef[BigNum,2],
-  where {
-      my $arr = $_;
-      $arr->[$_] < $arr->[$_+1] || return
-        for 0..($arr->@* - 2);
-        1;
-  },
-  message {
-      ArrayRef([BigNum,2])->validate($_)
-        or "Must be an array of monotonically increasing numbers with at lest two elements"
-    },
-  coercion => 1;
+declare BinEdges, as ArrayRef [ BigNum, 2 ], where {
+    my $arr = $_;
+    $arr->[$_] < $arr->[ $_ + 1 ] || return for 0 .. ( $arr->@* - 2 );
+    1;
+}, message {
+    ArrayRef( [ BigNum, 2 ] )->validate( $_ )
+      or
+      "Must be an array of monotonically increasing numbers with at lest two elements"
+}, coercion => 1;
 
 #
 # This file is part of CXC-Number
@@ -52,9 +48,9 @@ declare BinEdges,
 #
 
 coerce BinEdges,
-  from InstanceOf[ 'CXC::Number::Sequence' ],
+  from InstanceOf ['CXC::Number::Sequence'],
   via { $_->bignum->elements }
-  ;
+;
 
 1;
 
@@ -70,7 +66,7 @@ CXC::Number::Grid::Types - Type::Tiny types for CXC::Number::Grid
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 TYPES
 
@@ -78,15 +74,23 @@ version 0.06
 
 A array of numbers with at lest two members which is sorted by increasing value
 
-=head1 BUGS
+=head1 INTERNALS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
-to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
+=head1 SUPPORT
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/cxc-number
+
+and may be cloned from
+
+  https://gitlab.com/djerius/cxc-number.git
 
 =head1 SEE ALSO
 
