@@ -4,7 +4,7 @@ package CXC::Number::Sequence::Fixed;
 
 use Moo;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use namespace::clean;
 
@@ -37,7 +37,7 @@ CXC::Number::Sequence::Fixed - CXC::Number::Sequence with arbitrary values
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -49,15 +49,23 @@ version 0.06
 
 This subclass of L<CXC::Number::Sequence> specifies the exact elements in a sequence.
 
-=head1 BUGS
+=head1 INTERNALS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
-to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
+=head1 SUPPORT
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/cxc-number
+
+and may be cloned from
+
+  https://gitlab.com/djerius/cxc-number.git
 
 =head1 SEE ALSO
 
