@@ -6,7 +6,7 @@ use feature ':5.24';
 
 use Moo::Role;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use experimental 'signatures';
 use namespace::clean;
@@ -43,7 +43,7 @@ CXC::Number::Sequence::Role::BigNum - Role to return Math::BigFloats from Sequen
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -55,15 +55,23 @@ version 0.06
 A L<Moo> role providing a C<_convert> method which returns copies of the
 passed L<Math::BigFloat> arrays and scalars.
 
-=head1 BUGS
+=head1 INTERNALS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
-to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
+=head1 SUPPORT
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/cxc-number
+
+and may be cloned from
+
+  https://gitlab.com/djerius/cxc-number.git
 
 =head1 SEE ALSO
 
