@@ -7,7 +7,7 @@ use warnings;
 use feature ':5.24';
 use experimental 'signatures';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # ABSTRACT: sequence utilities
 
@@ -20,7 +20,11 @@ use Types::Common::Numeric qw( PositiveInt );
 
 use CXC::Number::Sequence::Failure -all;
 
-use Hash::Wrap 0.11 { -as => 'wrap_attrs_ro', -immutable => 1, -exists => 'has' };
+use Hash::Wrap 0.11 {
+    -as        => 'wrap_attrs_ro',
+    -immutable => 1,
+    -exists    => 'has'
+};
 use Hash::Wrap { -as => 'wrap_attrs_rw' };
 
 use namespace::clean;
@@ -118,11 +122,11 @@ sub buildargs_factory {
         map => HashRef [
             Dict [
                 flag => PositiveInt,
-                type => InstanceOf[ 'Type::Tiny' ],
+                type => InstanceOf ['Type::Tiny'],
             ]
         ],
         build     => Map [ PositiveInt, CodeRef ],
-        xvalidate => Optional [ ArrayRef[ Tuple [ PositiveInt, CodeRef ] ] ],
+        xvalidate => Optional [ ArrayRef [ Tuple [ PositiveInt, CodeRef ] ] ],
         adjust    => Optional [CodeRef],
     );
 
@@ -155,7 +159,8 @@ sub buildargs_factory {
         $attrs_set |= $arg->map->{$_}{flag} for keys %build_attrs;
 
         my $build = $arg->build->{$attrs_set}
-          // parameter_IllegalCombination->throw( "illegal combination of parameters: "
+          // parameter_IllegalCombination->throw(
+            "illegal combination of parameters: "
               . join( ', ', sort keys %build_attrs ) );
 
         if ( $arg->has_xvalidate ) {
@@ -181,19 +186,23 @@ sub buildargs_factory {
 
 
 # based on Mojo::Plugin::load_plugin, Mojo::Loader::load_class, Mojo::Util::camelize
-sub load_class( $name ) {
+sub load_class ( $name ) {
 
-  $name =  join '::', map { join('', map {ucfirst lc } split /_/) } split( /-/, $name )
-    unless $name =~ /^[A-Z]/;
+    $name = join '::', map {
+        join( '', map { ucfirst lc } split /_/ )
+    } split( /-/, $name )
+      unless $name =~ /^[A-Z]/;
 
-  for my $class ( "CXC::Number::Sequence::${name}", $name ) {
-      eval "require $class; 1" && return $class; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+    for my $class ( "CXC::Number::Sequence::${name}", $name ) {
+        ## no critic (BuiltinFunctions::ProhibitStringyEval)
+        eval "require $class; 1"
+          && return $class;
 
-      loadclass_CompileError->throw( "$class had a compile error: $@" )
-        unless $@ =~ m|Can't locate \Q@{[ $class =~ s{::}{/}gr . '.pm' ]}|;
-  }
+        loadclass_CompileError->throw( "$class had a compile error: $@" )
+          unless $@ =~ m|Can't locate \Q@{[ $class =~ s{::}{/}gr . '.pm' ]}|;
+    }
 
-  loadclass_NoClass->throw( "unable to find Sequence class matching $name" );
+    loadclass_NoClass->throw( "unable to find Sequence class matching $name" );
 }
 
 #
@@ -221,7 +230,7 @@ CXC::Number::Sequence::Utils - Utilities for CXC::Number::Sequence generators
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -315,17 +324,25 @@ adjust them in place as required.
 
 C<$class_or_submodule> is CamelCased.
 
+=head1 INTERNALS
+
 =for Pod::Coverage BUILDARGS
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
-to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
+=head2 Bugs
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/cxc-number
+
+and may be cloned from
+
+  https://gitlab.com/djerius/cxc-number.git
 
 =head1 SEE ALSO
 
