@@ -5,7 +5,7 @@ package CXC::Number::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Math::BigInt upgrade => 'Math::BigFloat';
 use Math::BigFloat;
@@ -31,35 +31,27 @@ class_type BigNum,
     message { 'Not a number or a Math::BigFloat' },
   };
 
-coerce BigNum,
-  from Num,
-  via {
-      my $bignum = Math::BigFloat->new( $_ );
-      $bignum->is_nan ? $_ : $bignum;
+coerce BigNum, from Num, via {
+    my $bignum = Math::BigFloat->new( $_ );
+    $bignum->is_nan ? $_ : $bignum;
 };
 
 
 
 
 
-declare BigPositiveNum,
-  as BigNum,
+declare BigPositiveNum, as BigNum,
   where { $_ > 0 },
   message { BigNum->validate( $_ ) or "$_ is not greater than zero" },
   coercion => 1;
 
-coerce BigPositiveNum,
-  from PositiveNum,
-  via { Math::BigFloat->new( $_ ) };
+coerce BigPositiveNum, from PositiveNum, via { Math::BigFloat->new( $_ ) };
 
 
 
 
 
-declare BigPositiveOrZeroNum,
-  as BigNum,
-  where { $_ >= 0 },
-  message {
+declare BigPositiveOrZeroNum, as BigNum, where { $_ >= 0 }, message {
     BigNum->validate( $_ )
       or "$_ is not greater than or equal to zero"
 }, coercion => 1;
@@ -82,9 +74,7 @@ declare BigInt,
     'Not an integer or a Math::BigInt'
   };
 
-coerce BigInt,
-  from Int,
-  via {
+coerce BigInt, from Int, via {
     Math::BigInt->new( $_ );
 };
 
@@ -94,15 +84,12 @@ coerce BigInt,
 
 
 
-declare BigPositiveInt,
-  as BigInt,
+declare BigPositiveInt, as BigInt,
   where { $_ > 0 },
   message { BigInt->validate( $_ ) or "$_ is not greater than zero" },
   coercion => 1;
 
-coerce BigPositiveInt,
-  from PositiveInt,
-  via { Math::BigFloat->new( $_ ) };
+coerce BigPositiveInt, from PositiveInt, via { Math::BigFloat->new( $_ ) };
 
 
 #
@@ -130,7 +117,7 @@ CXC::Number::Types - Type::Tiny types for CXC::Number
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 TYPES
 
@@ -148,15 +135,23 @@ version 0.06
 
 A BigInt > 0.
 
-=head1 BUGS
+=head1 INTERNALS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
-to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
+=head1 SUPPORT
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/cxc-number
+
+and may be cloned from
+
+  https://gitlab.com/djerius/cxc-number.git
 
 =head1 SEE ALSO
 
